@@ -64,8 +64,8 @@ def generate_input_func(user_args, hpc_args):
     """
 
     labels, coords = xyzp.load_xyz(user_args.xyz_file)
-    labels_nn = xyzp.remove_numbers(labels)
-    labels = xyzp.add_numbers(labels_nn)
+    labels_nn = xyzp.remove_label_indices(labels)
+    labels = xyzp.add_label_indices(labels_nn)
 
     sub = [x.capitalize() for x in user_args.sub]
 
