@@ -12,7 +12,6 @@ import xyz_py as xyzp
 import copy
 from numpy.typing import ArrayLike
 
-
 # These are VdW radii taken from the 2016/2017
 # CRC Handbook of physics of chemistry
 # Page 9-57
@@ -669,10 +668,10 @@ def create_com_file(charge, mult, f_name_head, labels, coords,
 
 def gen_input(f_name: str, labels: list[str], coords: ArrayLike,
               charge: int, mult: int, method: str, bs_spec: dict[str: str],
-              ecp_spec: dict = {str: str}, subiso=[], chelpg: str = '',
-              opt: bool = True, freq: bool = True, extra_route: list[str] = [],
-              extra_title: str = "", verbose: bool = True,
-              frozen: list = [str]):
+              ecp_spec: dict[str:str], subiso: list[int, float],
+              chelpg: str = '', opt: bool = True, freq: bool = True,
+              extra_route: list[str] = [], extra_title: str = "",
+              verbose: bool = True, frozen: list[str] = []):
     """
     Generates Gaussian input .com file ready for use with
     gaussian_suite submit
@@ -741,7 +740,21 @@ def gen_input(f_name: str, labels: list[str], coords: ArrayLike,
     # Get list of which elements are present
     unique_elements = list(set(labels_nn))
 
-    # Create basis list for this set of coordinates
+    # Trim down basis set specification to only include atoms present in
+    # labels
+    bs_spec = {
+        element: spec for element, spec in bs_spec.items()
+        if element in unique_elements
+    }
+
+    # Trim down ecp specification to only include atoms present in
+    # labels
+    ecp_spec = {
+        element: spec for element, spec in ecp_spec.items()
+        if element in unique_elements
+    }
+
+    # Create basis set and ecp specification
     basis, pseudo = create_basis(bs_spec, ecp_spec=ecp_spec)
     if len(pseudo):
         ecp = True
